public inbox for linux-pm@vger.kernel.org
 help / color / mirror / Atom feed
From: Daniel Lezcano <daniel.lezcano@linexp.org>
To: daniel.lezcano@linaro.org, rafael@kernel.org
Cc: linux-pm@vger.kernel.org, linux-kernel@vger.kernel.org,
	khilman@baylibre.com, abailon@baylibre.com,
	Amit Kucheria <amitk@kernel.org>, Zhang Rui <rui.zhang@intel.com>
Subject: [PATCH v3 09/12] thermal/core: Register with the trip points
Date: Sun,  3 Jul 2022 20:30:56 +0200	[thread overview]
Message-ID: <20220703183059.4133659-10-daniel.lezcano@linexp.org> (raw)
In-Reply-To: <20220703183059.4133659-1-daniel.lezcano@linexp.org>

As we added the thermal trip points structure in the thermal zone,
let's extend the thermal zone register function to have the thermal
trip structures as a parameter and store it in the 'trips' field of
the thermal zone structure.

Cc: Alexandre Bailon <abailon@baylibre.com>
Cc: Kevin Hilman <khilman@baylibre.com>
Cc; Eduardo Valentin <eduval@amazon.com>
Signed-off-by: Daniel Lezcano <daniel.lezcano@linexp.org>
---
 drivers/thermal/thermal_core.c | 22 +++++++++++++++++-----
 drivers/thermal/thermal_core.h |  4 ++--
 include/linux/thermal.h        |  6 ++++++
 3 files changed, 25 insertions(+), 7 deletions(-)

diff --git a/drivers/thermal/thermal_core.h b/drivers/thermal/thermal_core.h
index 84e341c1e0fc..bbe3ec26d12e 100644
--- a/drivers/thermal/thermal_core.h
+++ b/drivers/thermal/thermal_core.h
@@ -113,12 +113,12 @@ int thermal_build_list_of_policies(char *buf);
 /* Helpers */
 void thermal_zone_set_trips(struct thermal_zone_device *tz);
 
-static inline struct thermal_trip *thermal_zone_get_trips(struct thermal_zone *tz)
+static inline struct thermal_trip *thermal_zone_get_trips(struct thermal_zone_device *tz)
 {
 	return tz->trips;
 }
 
-static inline int thermal_zone_get_ntrips(struct thermal_zone *tz)
+static inline int thermal_zone_get_ntrips(struct thermal_zone_device *tz)
 {
 	return tz->ntrips;
 }
diff --git a/include/linux/thermal.h b/include/linux/thermal.h
index 3733e23b6359..8cbe237a92d0 100644
--- a/include/linux/thermal.h
+++ b/include/linux/thermal.h
@@ -379,8 +379,14 @@ void devm_thermal_zone_of_sensor_unregister(struct device *dev,
 struct thermal_zone_device *thermal_zone_device_register(const char *, int, int,
 		void *, struct thermal_zone_device_ops *,
 		struct thermal_zone_params *, int, int);
+
 void thermal_zone_device_unregister(struct thermal_zone_device *);
 
+struct thermal_zone_device *
+thermal_zone_device_register_with_trips(const char *, struct thermal_trip *, int, int,
+					void *, struct thermal_zone_device_ops *,
+					struct thermal_zone_params *, int, int);
+
 int thermal_zone_bind_cooling_device(struct thermal_zone_device *, int,
 				     struct thermal_cooling_device *,
 				     unsigned long, unsigned long,
diff --git a/drivers/thermal/thermal_core.c b/drivers/thermal/thermal_core.c
index 434a675da245..e865c41d2320 100644
--- a/drivers/thermal/thermal_core.c
+++ b/drivers/thermal/thermal_core.c
@@ -1167,8 +1167,9 @@ static void thermal_set_delay_jiffies(unsigned long *delay_jiffies, int delay_ms
 }
 
 /**
  * thermal_zone_device_register() - register a new thermal zone device
  * @type:	the thermal zone device type
+ * @trips:	a pointer to an array of thermal trips
  * @ntrips:	the number of trip points the thermal zone support
  * @mask:	a bit string indicating the writeablility of trip points
  * @devdata:	private device data
@@ -1191,10 +1192,10 @@ static void thermal_set_delay_jiffies(unsigned long *delay_jiffies, int delay_ms
  * IS_ERR*() helpers.
  */
 struct thermal_zone_device *
-thermal_zone_device_register(const char *type, int ntrips, int mask,
-			     void *devdata, struct thermal_zone_device_ops *ops,
-			     struct thermal_zone_params *tzp, int passive_delay,
-			     int polling_delay)
+thermal_zone_device_register_with_trips(const char *type, struct thermal_trip *trips, int ntrips, int mask,
+					void *devdata, struct thermal_zone_device_ops *ops,
+					struct thermal_zone_params *tzp, int passive_delay,
+					int polling_delay)
 {
 	struct thermal_zone_device *tz;
 	enum thermal_trip_type trip_type;
@@ -1256,6 +1257,7 @@ thermal_zone_device_register(const char *type, int ntrips, int mask,
 	tz->device.class = &thermal_class;
 	tz->devdata = devdata;
 	tz->ntrips = ntrips;
+	tz->trips = trips;
 
 	thermal_set_delay_jiffies(&tz->passive_delay_jiffies, passive_delay);
 	thermal_set_delay_jiffies(&tz->polling_delay_jiffies, polling_delay);
@@ -1331,6 +1333,16 @@ thermal_zone_device_register(const char *type, int ntrips, int mask,
 	kfree(tz);
 	return ERR_PTR(result);
 }
+
+struct thermal_zone_device *thermal_zone_device_register(const char *type, int ntrips, int mask,
+							 void *devdata, struct thermal_zone_device_ops *ops,
+							 struct thermal_zone_params *tzp, int passive_delay,
+							 int polling_delay)
+{
+	return thermal_zone_device_register_with_trips(type, NULL, ntrips, mask,
+						       devdata, ops, tzp,
+						       passive_delay, polling_delay);
+}
 EXPORT_SYMBOL_GPL(thermal_zone_device_register);
 
 /**
@@ -1167,8 +1167,9 @@ static void thermal_set_delay_jiffies(unsigned long *delay_jiffies, int delay_ms
 
 /**
- * thermal_zone_device_register() - register a new thermal zone device
+ * thermal_zone_device_register_with_trips() - register a new thermal zone device
  * @type:	the thermal zone device type
-- 
2.25.1


  parent reply	other threads:[~2022-07-03 18:31 UTC|newest]

Thread overview: 40+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2022-07-03 18:30 [PATCH v3 00/12] thermal OF rework Daniel Lezcano
2022-07-03 18:30 ` [PATCH v3 01/12] thermal/core: Remove duplicate information when an error occurs Daniel Lezcano
2022-07-04  7:38   ` Lukasz Luba
2022-07-03 18:30 ` [PATCH v3 02/12] thermal/of: Replace device node match with device node search Daniel Lezcano
2022-07-04  7:59   ` Lukasz Luba
2022-07-04 21:18     ` Daniel Lezcano
2022-07-03 18:30 ` [PATCH v3 03/12] thermal/of: Remove the device node pointer for thermal_trip Daniel Lezcano
2022-07-04  8:01   ` Lukasz Luba
2022-07-03 18:30 ` [PATCH v3 04/12] thermal/of: Move thermal_trip structure to thermal.h Daniel Lezcano
2022-07-04  8:04   ` Lukasz Luba
2022-07-03 18:30 ` [PATCH v3 05/12] thermal/core: Remove unneeded EXPORT_SYMBOLS Daniel Lezcano
2022-07-04  7:35   ` Lukasz Luba
2022-07-04 21:14     ` Daniel Lezcano
2022-07-05  7:30       ` Lukasz Luba
2022-07-05 14:20         ` Rafael J. Wysocki
2022-07-05 14:47           ` Lukasz Luba
2022-07-05 16:26       ` Todd Kjos
2022-07-03 18:30 ` [PATCH v3 06/12] thermal/core: Move thermal_set_delay_jiffies to static Daniel Lezcano
2022-07-04  8:05   ` Lukasz Luba
2022-07-03 18:30 ` [PATCH v3 07/12] thermal/core: Rename trips to ntrips Daniel Lezcano
2022-07-04  8:24   ` Lukasz Luba
2022-07-04 14:17     ` Zhang Rui
2022-07-04 21:19     ` Daniel Lezcano
2022-07-03 18:30 ` [PATCH v3 08/12] thermal/core: Add thermal_trip in thermal_zone Daniel Lezcano
2022-07-04  8:35   ` Lukasz Luba
2022-07-04 14:11   ` Zhang Rui
2022-07-04 21:20     ` Daniel Lezcano
2022-07-03 18:30 ` Daniel Lezcano [this message]
2022-07-04  8:32   ` [PATCH v3 09/12] thermal/core: Register with the trip points Lukasz Luba
2022-07-05  2:03   ` Zhang Rui
2022-07-05 13:59     ` Rafael J. Wysocki
2022-07-03 18:30 ` [PATCH v3 10/12] thermal/of: Store the trips in the thermal zone Daniel Lezcano
2022-07-04  8:38   ` Lukasz Luba
2022-07-03 18:30 ` [PATCH v3 11/12] thermal/of: Use thermal trips stored " Daniel Lezcano
2022-07-04 14:14   ` Zhang Rui
2022-07-04 21:24     ` Daniel Lezcano
2022-07-05  1:20       ` Zhang Rui
2022-07-05  6:44         ` Daniel Lezcano
2022-07-05  8:17           ` Zhang Rui
2022-07-03 18:30 ` [PATCH v3 12/12] thermal/of: Initialize trip points separately Daniel Lezcano

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20220703183059.4133659-10-daniel.lezcano@linexp.org \
    --to=daniel.lezcano@linexp.org \
    --cc=abailon@baylibre.com \
    --cc=amitk@kernel.org \
    --cc=daniel.lezcano@linaro.org \
    --cc=khilman@baylibre.com \
    --cc=linux-kernel@vger.kernel.org \
    --cc=linux-pm@vger.kernel.org \
    --cc=rafael@kernel.org \
    --cc=rui.zhang@intel.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox